<?php

/**
 * @file
 * Default theme implementation to configure blocks.
 *
 * Available variables:
 * - $block_regions: An array of regions. Keyed by name with the title as value.
 * - $block_listing: An array of blocks keyed by region and then delta.
 * - $form_submit: Form submit button.
 *
 * Each $block_listing[$region] contains an array of blocks for that region.
 *
 * Each $data in $block_listing[$region] contains:
 * - $data->region_title: Region title for the listed block.
 * - $data->block_title: Block title.
 * - $data->region_select: Drop-down menu for assigning a region.
 * - $data->weight_select: Drop-down menu for setting weights.
 * - $data->configure_link: Block configuration link.
 * - $data->delete_link: For deleting user added blocks.
 *
 * @see template_preprocess_block_admin_display_form()
 * @see theme_block_admin_display()
 *
 * @ingroup themeable
 */
?>
<?php
  // Add table javascript.
  drupal_add_js('misc/tableheader.js');
  drupal_add_js(drupal_get_path('module', 'curlypage') . '/curlypage.js');
  foreach ($groups as $group) {
    drupal_add_tabledrag('curlypages', 'match', 'sibling', 'curlypage-group-select', 'curlypage-group-' . $group->gid, NULL, FALSE);
    drupal_add_tabledrag('curlypages', 'order', 'sibling', 'curlypage-weight', 'curlypage-weight-' . $group->gid);
  }
?>
<table id="curlypages" class="sticky-enabled">
  <thead>
    <tr>
      <th><?php print t('Curlypage'); ?></th>
      <th><?php print t('Status'); ?></th>
      <th><?php print t('Link'); ?></th>
      <th><?php print t('Peel Position'); ?></th>
      <th><?php print t('Group'); ?></th>
      <th><?php print t('Weight'); ?></th>
      <th colspan="3"><?php print t('Operations'); ?></th>
    </tr>
  </thead>
  <tbody>
    <?php $row = 0; ?>
    <?php foreach ($groups as $group): ?>
      <tr class="group-title group-title-<?php print $group->gid; ?>">
        <td colspan="9"><?php print $group->name; ?></td>
      </tr>
      <tr class="group-message group-<?php print $group->gid; ?>-message <?php print empty($curlypage_listing[$group->gid]) ? 'group-empty' : 'group-populated'; ?>">
        <td colspan="9"><em><?php print t('No curlypages in this group'); ?></em></td>
      </tr>
      <?php foreach ($curlypage_listing[$group->gid] as $delta => $data): ?>
      <tr class="draggable <?php print $row % 2 == 0 ? 'odd' : 'even'; ?><?php print $data->row_class ? ' ' . $data->row_class : ''; ?>">
        <td class="curlypage"><?php print $data->curlypage_name; ?></td>
        <td><?php print $data->status_checkbox; ?></td>
        <td><?php print $data->curlypage_link; ?></td>
        <td><?php print $data->curlypage_peel_position; ?></td>
        <td><?php print $data->group_select; ?></td>
        <td><?php print $data->weight_select; ?></td>
        <td><?php print $data->edit_link; ?></td>
        <td><?php print $data->clone_link; ?></td>
        <td><?php print $data->delete_link; ?></td>
      </tr>
      <?php $row++; ?>
      <?php endforeach; ?>
    <?php endforeach; ?>
  </tbody>
</table>

<?php print $form_submit; ?>
