(function ($) {

/**
 * Move a curlypage in the curlypages table from one group to another via select list.
 *
 * This behavior is dependent on the tableDrag behavior, since it uses the
 * objects initialized in that behavior to update the row.
 */
Drupal.behaviors.curlypageDrag = {
  attach: function (context, settings) {
    // tableDrag is required and we should be on the curlypages admin page.
    if (typeof Drupal.tableDrag == 'undefined' || typeof Drupal.tableDrag.curlypages == 'undefined') {
      return;
    }

    var table = $('table#curlypages');
    var tableDrag = Drupal.tableDrag.curlypages; // Get the curlypages tableDrag object.

    // Add a handler for when a row is swapped, update empty groups.
    tableDrag.row.prototype.onSwap = function (swappedRow) {
      checkEmptyGroups(table, this);
    };

    // A custom message for the curlypages page specifically.
    Drupal.theme.tableDragChangedWarning = function () {
      return '<div class="messages warning">' + Drupal.theme('tableDragChangedMarker') + ' ' + Drupal.t('The changes to these curlypages will not be saved until the <em>Save curlypages</em> button is clicked.') + '</div>';
    };

    // Add a handler so when a row is dropped, update fields dropped into new groups.
    tableDrag.onDrop = function () {
      dragObject = this;
      // Use "group-message" row instead of "group" row because
      // "group-{group_name}-message" is less prone to regexp match errors.
      var groupRow = $(dragObject.rowObject.element).prevAll('tr.group-message').get(0);
      var groupName = groupRow.className.replace(/([^ ]+[ ]+)*group-([^ ]+)-message([ ]+[^ ]+)*/, '$2');
      var groupField = $('select.curlypage-group-select', dragObject.rowObject.element);
      // Check whether the newly picked group is available for this curlypage.
      if ($('option[value=' + groupName + ']', groupField).length == 0) {
        // If not, alert the user and keep the curlypage in its old group setting.
        alert(Drupal.t('The curlypage cannot be placed in this group.'));
        // Simulate that there was a selected element change, so the row is put
        // back to from where the user tried to drag it.
        groupField.change();
      }
      else if ($(dragObject.rowObject.element).prev('tr').is('.group-message')) {
        var weightField = $('select.curlypage-weight', dragObject.rowObject.element);
        var oldGroupName = weightField[0].className.replace(/([^ ]+[ ]+)*curlypage-weight-([^ ]+)([ ]+[^ ]+)*/, '$2');

        if (!groupField.is('.curlypage-group-' + groupName)) {
          groupField.removeClass('curlypage-group-' + oldGroupName).addClass('curlypage-group-' + groupName);
          weightField.removeClass('curlypage-weight-' + oldGroupName).addClass('curlypage-weight-' + groupName);
          groupField.val(groupName);
        }
      }
    };

    // Add the behavior to each group select list.
    $('select.curlypage-group-select', context).once('curlypage-group-select', function () {
      $(this).change(function (event) {
        // Make our new row and select field.
        var row = $(this).closest('tr');
        var select = $(this);
        tableDrag.rowObject = new tableDrag.row(row);

        // Find the correct group and insert the row as the last in the group.
        table.find('.group-' + select[0].value + '-message').nextUntil('.group-message').last().before(row);

        // Modify empty groups with added or removed fields.
        checkEmptyGroups(table, row);
        // Remove focus from selectbox.
        select.get(0).blur();
      });
    });

    var checkEmptyGroups = function (table, rowObject) {
      $('tr.group-message', table).each(function () {
        // If the dragged row is in this group, but above the message row, swap it down one space.
        if ($(this).prev('tr').get(0) == rowObject.element) {
          // Prevent a recursion problem when using the keyboard to move rows up.
          if ((rowObject.method != 'keyboard' || rowObject.direction == 'down')) {
            rowObject.swap('after', this);
          }
        }
        // This group has become empty.
        if ($(this).next('tr').is(':not(.draggable)') || $(this).next('tr').length == 0) {
          $(this).removeClass('group-populated').addClass('group-empty');
        }
        // This group has become populated.
        else if ($(this).is('.group-empty')) {
          $(this).removeClass('group-empty').addClass('group-populated');
        }
      });
    };
  }
};

})(jQuery);

